Learn R Programming

CorMID (version 0.3.1)

prep: Example data as used in function CorMID.

Description

Example data as used in function CorMID.

Usage

data(prep)

Arguments

Format

A list of 36 example metabolites.

name

The compound name.

int

A numeric matrix providing peak intensities of isotopologues containing biological carbon (rows) over ten samples (columns).

fml

A character vector of the chemical formula of the compound amended by attributes for the number of biological carbons 'nbio' and the number of measured mass isotopologues 'nmz'.