CorMID.Example data as used in function CorMID.
data(prep)A list of 36 example metabolites.
The compound name.
A numeric matrix providing peak intensities of isotopologues containing biological carbon (rows) over ten samples (columns).
A character vector of the chemical formula of the compound amended by attributes for the number of biological carbons 'nbio' and the number of measured mass isotopologues 'nmz'.